##################################################
#
# warehouse_jump.bsl
#
#################################################
#
# This BSL file is a part of a wall climb demo.
# Function "f_PlayerClimbMaster" must be forked from somewhere
# (be it main, save point or whatever) in order to make this script work.
#
##################################################
#
#
#
#
#
#################################################
#                  Variables                    #
#################################################
#####
# "vPlayerClimbID" is used to indicate the type of the climb OBAN animation to be applied on the climber.
#####
# "vPlayerCanClimb" indicates that tapping the jump key makes the player character perform climb action.
#####
# "vPlayer1" is used to send a signal that player is on top of the furniture.
#      It enables the climb action for A.I. characters.
#####

  var int    vPlayerClimbID  = 0;
  var bool   vPlayerCanClimb = 0;
  var bool   vPlayer1        = 0;

#################################################


#################################################
#              BSL Functions                    #
#################################################
#####
# "f_ClimbHitCancel" cancels envanim if character is hit during climb action.
#####
# "f_Climb" makes the character perform requested OBAN env animation and the climbing TRAM animation.
#####
# "f_PlayerClimbMaster" is a master function for player climb action.
#      If player taps jump key, the function checks whether the "vPlayerCanClimb"
#      is true. If yes, then according to the "vPlayerClimbID" it picks correct OBAN.
#####

func void f_ClimbHitCancel(string ai_name)
{
  chr_wait_animtype(ai_name, Knockdown_Head, Knockdown_Head_Behind)
  chr_envanim_stop(ai_name)
}

func void f_Climb(string ai_name, string vOBANname, string vFILMname)
{
  chr_playback_block(ai_name, vFILMname, fromhere)
  chr_envanim(ai_name, vOBANname)
  chr_animate(ai_name, KONOKOtestjump)
  fork f_ClimbHitCancel(ai_name)
  sleep 70
}


func void f_PlayerClimbMaster(void)
{
  chr_wait_animtype(0, Jump)
  if ( vPlayerCanClimb )
  {
    input 0
    if( vPlayerClimbID eq 1 )
    {
      f_Climb("0", "Jump1", "deg000")
    }
    if( vPlayerClimbID eq 2 )
    {
      f_Climb("0", "Jump2", "deg000")
    }
    if( vPlayerClimbID eq 3 )
    {
      f_Climb("0", "Jump3", "deg090")
    }
    if( vPlayerClimbID eq 4 )
    {
      f_Climb("0", "Jump4", "deg180")
    }
    if( vPlayerClimbID eq 5 )
    {
      f_Climb("0", "Jump5", "deg180")
    }
    if( vPlayerClimbID > 5 )
    {
      dmsg CLIMB_ID_ERROR
      sleep 180
      message_remove
    }
    sleep 1
    input 1
    chr_envanim_stop 0
  }
  sleep 30
  fork f_PlayerClimbMaster() 
}



#################################################
#       jump TrigVolume event functions         #
#################################################
#####
# "f_TrEnabler" is an auxiliary function which helps to drastically prolong time
#      till script exceed error (caused by trigvolume "inside" event).
#####
# "tr_jumpX_entry" are functions called by respective trigvolumes when character enters.
#     These functions filter player character and if the player entered, they set
#     "vPlayerCanClimb=1" and "vPlayerClimbID=ID of the climb action".
#     IDs of climb actions are set here in BSL script, it is only an auxiliary variable.
#####
# "tr_jumpX_exit" are functions called by respective trigvolumes when character exits.
#     These functions filter player character and if the player exited, they set
#     "vPlayerCanClimb=0" and "vPlayerClimbID=0".
#####
# "tr_jumpX_inside" are functions called by respective trigvolumes when character dwells inside.
#     These functions filter NON-player character and if the NON-player character is inside,
#     they check for "vPlayer1" variable. If it is true, then A.I. character
#     is issued to perform climb action.
#####


func void f_TrEnabler(string vTrVol)
{
  trigvolume_enable (vTrVol, 0, inside)
  sleep 90
  trigvolume_enable (vTrVol, 1, inside)
}

#####
### trigger volume "tr_jump1" event functions ###
#####

func void tr_jump1_entry(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 1
    vPlayerClimbID = 1
  }
}
func void tr_jump1_exit(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 0
    vPlayerClimbID = 0
  }
}
func void tr_jump1_inside(string ai_name)
{
  fork f_TrEnabler("tr_jump1")
  if( !(chr_is_player(ai_name)) and (vPlayer1) )
  {
    f_Climb(ai_name, "Jump1", "deg000")
    chr_playback_block(ai_name, "deg000", fromhere)
  }
}

#####
### trigger volume "tr_jump2" event functions ###
#####

func void tr_jump2_entry(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 1
    vPlayerClimbID = 2
  }
}
func void tr_jump2_exit(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 0
    vPlayerClimbID = 0
  }
}
func void tr_jump2_inside(string ai_name)
{
  fork f_TrEnabler("tr_jump2")
  if( !(chr_is_player(ai_name)) and (vPlayer1) )
  {
    f_Climb(ai_name, "Jump2", "deg000")
    chr_playback_block(ai_name, "deg000", fromhere)
  }
}

#####
### trigger volume "tr_jump3" event functions ###
#####

func void tr_jump3_entry(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 1
    vPlayerClimbID = 3
  }
}
func void tr_jump3_exit(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 0
    vPlayerClimbID = 0
  }
}
func void tr_jump3_inside(string ai_name)
{
  fork f_TrEnabler("tr_jump3")
  if( !(chr_is_player(ai_name)) and (vPlayer1) )
  {
    f_Climb(ai_name, "Jump3", "deg090")
    chr_playback_block(ai_name, "deg090", fromhere)
  }
}

#####
### trigger volume "tr_jump4" event functions ###
#####

func void tr_jump4_entry(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 1
    vPlayerClimbID = 4
  }
}
func void tr_jump4_exit(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 0
    vPlayerClimbID = 0
  }
}
func void tr_jump4_inside(string ai_name)
{
  fork f_TrEnabler("tr_jump4")
  if( !(chr_is_player(ai_name)) and (vPlayer1) )
  {
    f_Climb(ai_name, "Jump4", "deg180")
    chr_playback_block(ai_name, "deg180", fromhere)
  }
}

#####
### trigger volume "tr_jump5" event functions ###
#####

func void tr_jump5_entry(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 1
    vPlayerClimbID = 5
  }
}
func void tr_jump5_exit(string ai_name)
{
  if( chr_is_player(ai_name) )
  {
    vPlayerCanClimb = 0
    vPlayerClimbID = 0
  }
}
func void tr_jump5_inside(string ai_name)
{
  fork f_TrEnabler("tr_jump5")
  if( !(chr_is_player(ai_name)) and (vPlayer1) )
  {
    f_Climb(ai_name, "Jump5", "deg180")
    chr_playback_block(ai_name, "deg180", fromhere)
  }
}

func void tr_jump7_enter(string ai_name)
{	
 chr_wait_animtype(0, Jump)
  chr_animate 0 KONOKOtestjump2
}



#################################################
#  player position TrigVolume event functions   #
#################################################
#####
# "tr_topX_entry" are functions called by respective trigvolumes
#     only when player character enters.
#     These functions specify obstacle traversal for A.I. characters.
#####
# "tr_topX_exit" are functions called by respective trigvolumes
#     only when player character exits.
#     These functions stop obstacle traversal for A.I. characters.
#####

func void tr_top1_entry(string ai_name)
{
  vPlayer1 = 1
}
func void tr_top1_exit(string ai_name)
{
  vPlayer1 = 0
}